pub struct ModelRecord {Show 14 fields
pub id: String,
pub display_name: String,
pub publisher: String,
pub role: ModelRole,
pub availability: Availability,
pub visibility: Visibility,
pub protocol: ModelProtocol,
pub pricing: PricingPerMillion,
pub limits: ModelLimits,
pub capabilities: ModelCapabilities,
pub provenance: CapabilityProvenance,
pub documentation_url: Option<String>,
pub catalog_added_at: Option<NaiveDate>,
pub raw: Value,
}Expand description
Normalized Workers AI model record - one source of truth for the picker, the fallback list, and generated YAML.
Fields
id: Stringdisplay_name: Stringpublisher: Stringrole: ModelRoleavailability: Availabilityvisibility: Visibilityprotocol: ModelProtocolpricing: PricingPerMillionlimits: ModelLimitscapabilities: ModelCapabilitiesprovenance: CapabilityProvenancedocumentation_url: Option<String>catalog_added_at: Option<NaiveDate>raw: ValueImplementations
Sourceimpl ModelRecord
impl ModelRecord
Sourcepub fn from_openrouter(item: &Value) -> Option<Self>
pub fn from_openrouter(item: &Value) -> Option<Self>
Normalize one OpenRouter-format catalog entry.
Sourcepub fn eligible_for_primary_picker(&self) -> bool
pub fn eligible_for_primary_picker(&self) -> bool
True when the model may appear in the primary coding picker.
Sourcepub fn is_default(&self) -> bool
pub fn is_default(&self) -> bool
True when the model is the project’s development default.